function [residual, g1, g2, g3] = rbc_original_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [nperiods by M_.exo_nbr] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   steady_state  [M_.endo_nbr by 1] double       vector of steady state values
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations.
%                                          Dynare may prepend auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(15, 1);
T17 = params(1)/params(8)*y(19)^(-params(3));
T27 = params(5)*exp(y(21))*(y(6)/y(20))^(params(5)-1);
T30 = T27+1-params(4);
T35 = params(2)*y(5)^params(3);
T58 = exp(y(8))*y(1)^params(5);
T60 = y(7)^(1-params(5));
lhs =y(5)^(-params(3));
rhs =T17*T30;
residual(1)= lhs-rhs;
lhs =T35/(1-y(7));
rhs =y(11);
residual(2)= lhs-rhs;
lhs =params(8)*y(6);
rhs =(1-params(4))*y(1)+y(12);
residual(3)= lhs-rhs;
lhs =y(4);
rhs =y(5)+y(12)+params(14)*exp(y(9));
residual(4)= lhs-rhs;
lhs =y(4);
rhs =T58*T60;
residual(5)= lhs-rhs;
lhs =y(11);
rhs =y(4)*(1-params(5))/y(7);
residual(6)= lhs-rhs;
lhs =y(10);
rhs =y(4)*params(5)*4/y(1);
residual(7)= lhs-rhs;
lhs =y(8);
rhs =params(6)*y(2)+x(it_, 1);
residual(8)= lhs-rhs;
lhs =y(9);
rhs =params(7)*y(3)+x(it_, 2);
residual(9)= lhs-rhs;
lhs =y(13);
rhs =log(y(4));
residual(10)= lhs-rhs;
lhs =y(14);
rhs =log(y(6));
residual(11)= lhs-rhs;
lhs =y(15);
rhs =log(y(5));
residual(12)= lhs-rhs;
lhs =y(16);
rhs =log(y(7));
residual(13)= lhs-rhs;
lhs =y(17);
rhs =log(y(11));
residual(14)= lhs-rhs;
lhs =y(18);
rhs =log(y(12));
residual(15)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(15, 23);

  %
  % Jacobian matrix
  %

T128 = getPowerDeriv(y(6)/y(20),params(5)-1,1);
  g1(1,5)=getPowerDeriv(y(5),(-params(3)),1);
  g1(1,19)=(-(T30*params(1)/params(8)*getPowerDeriv(y(19),(-params(3)),1)));
  g1(1,6)=(-(T17*params(5)*exp(y(21))*1/y(20)*T128));
  g1(1,20)=(-(T17*params(5)*exp(y(21))*T128*(-y(6))/(y(20)*y(20))));
  g1(1,21)=(-(T17*T27));
  g1(2,5)=params(2)*getPowerDeriv(y(5),params(3),1)/(1-y(7));
  g1(2,7)=T35/((1-y(7))*(1-y(7)));
  g1(2,11)=(-1);
  g1(3,1)=(-(1-params(4)));
  g1(3,6)=params(8);
  g1(3,12)=(-1);
  g1(4,4)=1;
  g1(4,5)=(-1);
  g1(4,9)=(-(params(14)*exp(y(9))));
  g1(4,12)=(-1);
  g1(5,4)=1;
  g1(5,1)=(-(T60*exp(y(8))*getPowerDeriv(y(1),params(5),1)));
  g1(5,7)=(-(T58*getPowerDeriv(y(7),1-params(5),1)));
  g1(5,8)=(-(T58*T60));
  g1(6,4)=(-((1-params(5))/y(7)));
  g1(6,7)=(-((-(y(4)*(1-params(5))))/(y(7)*y(7))));
  g1(6,11)=1;
  g1(7,4)=(-(params(5)*4/y(1)));
  g1(7,1)=(-((-(y(4)*params(5)*4))/(y(1)*y(1))));
  g1(7,10)=1;
  g1(8,2)=(-params(6));
  g1(8,8)=1;
  g1(8,22)=(-1);
  g1(9,3)=(-params(7));
  g1(9,9)=1;
  g1(9,23)=(-1);
  g1(10,4)=(-(1/y(4)));
  g1(10,13)=1;
  g1(11,6)=(-(1/y(6)));
  g1(11,14)=1;
  g1(12,5)=(-(1/y(5)));
  g1(12,15)=1;
  g1(13,7)=(-(1/y(7)));
  g1(13,16)=1;
  g1(14,11)=(-(1/y(11)));
  g1(14,17)=1;
  g1(15,12)=(-(1/y(12)));
  g1(15,18)=1;

if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],15,529);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],15,12167);
end
end
end
end
