function [residual, g1, g2, g3] = rbc_original_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations.
%                                          Dynare may prepend or append auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g3        [M_.endo_nbr by (M_.endo_nbr)^3] double   Third derivatives matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 15, 1);

%
% Model equations
%

T11 = y(2)^(-params(3));
T15 = T11*params(1)/params(8);
T25 = params(5)*exp(y(5))*(y(3)/y(4))^(params(5)-1);
T28 = T25+1-params(4);
T33 = params(2)*y(2)^params(3);
T52 = exp(y(5))*y(3)^params(5);
T54 = y(4)^(1-params(5));
lhs =T11;
rhs =T15*T28;
residual(1)= lhs-rhs;
lhs =T33/(1-y(4));
rhs =y(8);
residual(2)= lhs-rhs;
lhs =params(8)*y(3);
rhs =y(3)*(1-params(4))+y(9);
residual(3)= lhs-rhs;
lhs =y(1);
rhs =y(2)+y(9)+params(14)*exp(y(6));
residual(4)= lhs-rhs;
lhs =y(1);
rhs =T52*T54;
residual(5)= lhs-rhs;
lhs =y(8);
rhs =y(1)*(1-params(5))/y(4);
residual(6)= lhs-rhs;
lhs =y(7);
rhs =y(1)*params(5)*4/y(3);
residual(7)= lhs-rhs;
lhs =y(5);
rhs =y(5)*params(6)+x(1);
residual(8)= lhs-rhs;
lhs =y(6);
rhs =y(6)*params(7)+x(2);
residual(9)= lhs-rhs;
lhs =y(10);
rhs =log(y(1));
residual(10)= lhs-rhs;
lhs =y(11);
rhs =log(y(3));
residual(11)= lhs-rhs;
lhs =y(12);
rhs =log(y(2));
residual(12)= lhs-rhs;
lhs =y(13);
rhs =log(y(4));
residual(13)= lhs-rhs;
lhs =y(14);
rhs =log(y(8));
residual(14)= lhs-rhs;
lhs =y(15);
rhs =log(y(9));
residual(15)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(15, 15);

  %
  % Jacobian matrix
  %

T100 = getPowerDeriv(y(2),(-params(3)),1);
T110 = getPowerDeriv(y(3)/y(4),params(5)-1,1);
  g1(1,2)=T100-T28*params(1)/params(8)*T100;
  g1(1,3)=(-(T15*params(5)*exp(y(5))*1/y(4)*T110));
  g1(1,4)=(-(T15*params(5)*exp(y(5))*T110*(-y(3))/(y(4)*y(4))));
  g1(1,5)=(-(T15*T25));
  g1(2,2)=params(2)*getPowerDeriv(y(2),params(3),1)/(1-y(4));
  g1(2,4)=T33/((1-y(4))*(1-y(4)));
  g1(2,8)=(-1);
  g1(3,3)=params(8)-(1-params(4));
  g1(3,9)=(-1);
  g1(4,1)=1;
  g1(4,2)=(-1);
  g1(4,6)=(-(params(14)*exp(y(6))));
  g1(4,9)=(-1);
  g1(5,1)=1;
  g1(5,3)=(-(T54*exp(y(5))*getPowerDeriv(y(3),params(5),1)));
  g1(5,4)=(-(T52*getPowerDeriv(y(4),1-params(5),1)));
  g1(5,5)=(-(T52*T54));
  g1(6,1)=(-((1-params(5))/y(4)));
  g1(6,4)=(-((-(y(1)*(1-params(5))))/(y(4)*y(4))));
  g1(6,8)=1;
  g1(7,1)=(-(params(5)*4/y(3)));
  g1(7,3)=(-((-(y(1)*params(5)*4))/(y(3)*y(3))));
  g1(7,7)=1;
  g1(8,5)=1-params(6);
  g1(9,6)=1-params(7);
  g1(10,1)=(-(1/y(1)));
  g1(10,10)=1;
  g1(11,3)=(-(1/y(3)));
  g1(11,11)=1;
  g1(12,2)=(-(1/y(2)));
  g1(12,12)=1;
  g1(13,4)=(-(1/y(4)));
  g1(13,13)=1;
  g1(14,8)=(-(1/y(8)));
  g1(14,14)=1;
  g1(15,9)=(-(1/y(9)));
  g1(15,15)=1;
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],15,225);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],15,3375);
end
end
end
end
