function [residual, g1, g2, g3] = rbc_var_block_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [nperiods by M_.exo_nbr] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   steady_state  [M_.endo_nbr by 1] double       vector of steady state values
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations.
%                                          Dynare may prepend auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(16, 1);
T20 = params(1)/params(7)*y(20)^(-params(2));
T30 = params(4)*exp(y(22))*(y(6)/y(21))^(params(4)-1);
T33 = T30+1-params(3);
T36 = y(5)^params(2);
T37 = y(19)*T36;
T60 = exp(y(8))*y(1)^params(4);
T62 = y(7)^(1-params(4));
lhs =y(19);
rhs =(steady_state(16));
residual(1)= lhs-rhs;
lhs =y(5)^(-params(2));
rhs =T20*T33;
residual(2)= lhs-rhs;
lhs =T37/(1-y(7));
rhs =y(11);
residual(3)= lhs-rhs;
lhs =params(7)*y(6);
rhs =(1-params(3))*y(1)+y(12);
residual(4)= lhs-rhs;
lhs =y(4);
rhs =y(5)+y(12)+params(13)*exp(y(9));
residual(5)= lhs-rhs;
lhs =y(4);
rhs =T60*T62;
residual(6)= lhs-rhs;
lhs =y(11);
rhs =y(4)*(1-params(4))/y(7);
residual(7)= lhs-rhs;
lhs =y(10);
rhs =y(4)*params(4)*4/y(1);
residual(8)= lhs-rhs;
lhs =y(8);
rhs =params(5)*y(2)+x(it_, 1);
residual(9)= lhs-rhs;
lhs =y(9);
rhs =params(6)*y(3)+x(it_, 2);
residual(10)= lhs-rhs;
lhs =y(13);
rhs =log(y(4));
residual(11)= lhs-rhs;
lhs =y(14);
rhs =log(y(6));
residual(12)= lhs-rhs;
lhs =y(15);
rhs =log(y(5));
residual(13)= lhs-rhs;
lhs =y(16);
rhs =log(y(7));
residual(14)= lhs-rhs;
lhs =y(17);
rhs =log(y(11));
residual(15)= lhs-rhs;
lhs =y(18);
rhs =log(y(12));
residual(16)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(16, 24);

  %
  % Jacobian matrix
  %

T130 = getPowerDeriv(y(6)/y(21),params(4)-1,1);
  g1(1,19)=1;
  g1(2,5)=getPowerDeriv(y(5),(-params(2)),1);
  g1(2,20)=(-(T33*params(1)/params(7)*getPowerDeriv(y(20),(-params(2)),1)));
  g1(2,6)=(-(T20*params(4)*exp(y(22))*1/y(21)*T130));
  g1(2,21)=(-(T20*params(4)*exp(y(22))*T130*(-y(6))/(y(21)*y(21))));
  g1(2,22)=(-(T20*T30));
  g1(3,5)=y(19)*getPowerDeriv(y(5),params(2),1)/(1-y(7));
  g1(3,7)=T37/((1-y(7))*(1-y(7)));
  g1(3,11)=(-1);
  g1(3,19)=T36/(1-y(7));
  g1(4,1)=(-(1-params(3)));
  g1(4,6)=params(7);
  g1(4,12)=(-1);
  g1(5,4)=1;
  g1(5,5)=(-1);
  g1(5,9)=(-(params(13)*exp(y(9))));
  g1(5,12)=(-1);
  g1(6,4)=1;
  g1(6,1)=(-(T62*exp(y(8))*getPowerDeriv(y(1),params(4),1)));
  g1(6,7)=(-(T60*getPowerDeriv(y(7),1-params(4),1)));
  g1(6,8)=(-(T60*T62));
  g1(7,4)=(-((1-params(4))/y(7)));
  g1(7,7)=(-((-(y(4)*(1-params(4))))/(y(7)*y(7))));
  g1(7,11)=1;
  g1(8,4)=(-(params(4)*4/y(1)));
  g1(8,1)=(-((-(y(4)*params(4)*4))/(y(1)*y(1))));
  g1(8,10)=1;
  g1(9,2)=(-params(5));
  g1(9,8)=1;
  g1(9,23)=(-1);
  g1(10,3)=(-params(6));
  g1(10,9)=1;
  g1(10,24)=(-1);
  g1(11,4)=(-(1/y(4)));
  g1(11,13)=1;
  g1(12,6)=(-(1/y(6)));
  g1(12,14)=1;
  g1(13,5)=(-(1/y(5)));
  g1(13,15)=1;
  g1(14,7)=(-(1/y(7)));
  g1(14,16)=1;
  g1(15,11)=(-(1/y(11)));
  g1(15,17)=1;
  g1(16,12)=(-(1/y(12)));
  g1(16,18)=1;

if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],16,576);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],16,13824);
end
end
end
end
