function [residual, g1, g2, g3] = rbc_var_block_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations.
%                                          Dynare may prepend or append auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g3        [M_.endo_nbr by (M_.endo_nbr)^3] double   Third derivatives matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 16, 1);

%
% Model equations
%

T14 = y(2)^(-params(2));
T18 = T14*params(1)/params(7);
T28 = params(4)*exp(y(5))*(y(3)/y(4))^(params(4)-1);
T31 = T28+1-params(3);
T34 = y(2)^params(2);
T35 = y(16)*T34;
T54 = exp(y(5))*y(3)^params(4);
T56 = y(4)^(1-params(4));
lhs =y(16);
rhs =(y(16));
residual(1)= lhs-rhs;
lhs =T14;
rhs =T18*T31;
residual(2)= lhs-rhs;
lhs =T35/(1-y(4));
rhs =y(8);
residual(3)= lhs-rhs;
lhs =params(7)*y(3);
rhs =y(3)*(1-params(3))+y(9);
residual(4)= lhs-rhs;
lhs =y(1);
rhs =y(2)+y(9)+params(13)*exp(y(6));
residual(5)= lhs-rhs;
lhs =y(1);
rhs =T54*T56;
residual(6)= lhs-rhs;
lhs =y(8);
rhs =y(1)*(1-params(4))/y(4);
residual(7)= lhs-rhs;
lhs =y(7);
rhs =y(1)*params(4)*4/y(3);
residual(8)= lhs-rhs;
lhs =y(5);
rhs =y(5)*params(5)+x(1);
residual(9)= lhs-rhs;
lhs =y(6);
rhs =y(6)*params(6)+x(2);
residual(10)= lhs-rhs;
lhs =y(10);
rhs =log(y(1));
residual(11)= lhs-rhs;
lhs =y(11);
rhs =log(y(3));
residual(12)= lhs-rhs;
lhs =y(12);
rhs =log(y(2));
residual(13)= lhs-rhs;
lhs =y(13);
rhs =log(y(4));
residual(14)= lhs-rhs;
lhs =y(14);
rhs =log(y(8));
residual(15)= lhs-rhs;
lhs =y(15);
rhs =log(y(9));
residual(16)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(16, 16);

  %
  % Jacobian matrix
  %

T102 = getPowerDeriv(y(2),(-params(2)),1);
T112 = getPowerDeriv(y(3)/y(4),params(4)-1,1);
  g1(2,2)=T102-T31*params(1)/params(7)*T102;
  g1(2,3)=(-(T18*params(4)*exp(y(5))*1/y(4)*T112));
  g1(2,4)=(-(T18*params(4)*exp(y(5))*T112*(-y(3))/(y(4)*y(4))));
  g1(2,5)=(-(T18*T28));
  g1(3,2)=y(16)*getPowerDeriv(y(2),params(2),1)/(1-y(4));
  g1(3,4)=T35/((1-y(4))*(1-y(4)));
  g1(3,8)=(-1);
  g1(3,16)=T34/(1-y(4));
  g1(4,3)=params(7)-(1-params(3));
  g1(4,9)=(-1);
  g1(5,1)=1;
  g1(5,2)=(-1);
  g1(5,6)=(-(params(13)*exp(y(6))));
  g1(5,9)=(-1);
  g1(6,1)=1;
  g1(6,3)=(-(T56*exp(y(5))*getPowerDeriv(y(3),params(4),1)));
  g1(6,4)=(-(T54*getPowerDeriv(y(4),1-params(4),1)));
  g1(6,5)=(-(T54*T56));
  g1(7,1)=(-((1-params(4))/y(4)));
  g1(7,4)=(-((-(y(1)*(1-params(4))))/(y(4)*y(4))));
  g1(7,8)=1;
  g1(8,1)=(-(params(4)*4/y(3)));
  g1(8,3)=(-((-(y(1)*params(4)*4))/(y(3)*y(3))));
  g1(8,7)=1;
  g1(9,5)=1-params(5);
  g1(10,6)=1-params(6);
  g1(11,1)=(-(1/y(1)));
  g1(11,10)=1;
  g1(12,3)=(-(1/y(3)));
  g1(12,11)=1;
  g1(13,2)=(-(1/y(2)));
  g1(13,12)=1;
  g1(14,4)=(-(1/y(4)));
  g1(14,13)=1;
  g1(15,8)=(-(1/y(8)));
  g1(15,14)=1;
  g1(16,9)=(-(1/y(9)));
  g1(16,15)=1;
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],16,256);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],16,4096);
end
end
end
end
